kenchi\.outlier\_detection\.angle\_based module
===============================================

.. automodule:: kenchi.outlier_detection.angle_based
    :members:
    :undoc-members:
    :show-inheritance:
